@@ -14,3 +14,7 @@ CHANGELINK_URL          = 'http://api.unknownvpn.org/changelink'
 GETCONNECTIONS_URL      = 'http://api.unknownvpn.org/getconnections'
 CHANGELOCATION_URL      = 'http://api.unknownvpn.org/changelocation'
 CHANGENAME_URL          = 'http://api.unknownvpn.org/changename'
+BUYMOREUSER_URL         = 'http://api.unknownvpn.org/buymoreuser'
+BUYMORETRAFFIC_URL      = 'http://api.unknownvpn.org/buymoretraffic'
+RENEWSERVICE_URL        = 'http://api.unknownvpn.org/extensionservice'
+AUTOPAY_URL             = 'http://api.unknownvpn.org/setautopay'
\ No newline at end of file
